summaryrefslogtreecommitdiffstats
path: root/vcs/subversion
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/subversion')
-rw-r--r--vcs/subversion/CMakeLists.txt26
-rw-r--r--vcs/subversion/Makefile.am30
-rw-r--r--vcs/subversion/integrator/CMakeLists.txt4
-rw-r--r--vcs/subversion/integrator/Makefile.am4
-rw-r--r--vcs/subversion/integrator/kdevsubversionintegrator.desktop (renamed from vcs/subversion/integrator/tdevsubversionintegrator.desktop)0
-rw-r--r--vcs/subversion/integrator/subversionintegrator.cpp10
-rw-r--r--vcs/subversion/integrator/subversionintegrator.h4
-rw-r--r--vcs/subversion/integrator/svnintegratordlg.cpp2
-rw-r--r--vcs/subversion/integrator/svnintegratordlg.h2
-rw-r--r--vcs/subversion/kdevpart_subversion.rc (renamed from vcs/subversion/tdevpart_subversion.rc)0
-rw-r--r--vcs/subversion/kdevsubversion.desktop (renamed from vcs/subversion/tdevsubversion.desktop)2
-rw-r--r--vcs/subversion/kdevsvn+file.protocol (renamed from vcs/subversion/tdevsvn+file.protocol)0
-rw-r--r--vcs/subversion/kdevsvn+http.protocol (renamed from vcs/subversion/tdevsvn+http.protocol)0
-rw-r--r--vcs/subversion/kdevsvn+https.protocol (renamed from vcs/subversion/tdevsvn+https.protocol)0
-rw-r--r--vcs/subversion/kdevsvn+ssh.protocol (renamed from vcs/subversion/tdevsvn+ssh.protocol)0
-rw-r--r--vcs/subversion/kdevsvn+svn.protocol (renamed from vcs/subversion/tdevsvn+svn.protocol)0
-rw-r--r--vcs/subversion/kdevsvnd.cpp (renamed from vcs/subversion/tdevsvnd.cpp)22
-rw-r--r--vcs/subversion/kdevsvnd.desktop (renamed from vcs/subversion/tdevsvnd.desktop)0
-rw-r--r--vcs/subversion/kdevsvnd.h (renamed from vcs/subversion/tdevsvnd.h)6
-rw-r--r--vcs/subversion/kdevsvnd_widgets.cpp (renamed from vcs/subversion/tdevsvnd_widgets.cpp)4
-rw-r--r--vcs/subversion/kdevsvnd_widgets.h (renamed from vcs/subversion/tdevsvnd_widgets.h)4
-rw-r--r--vcs/subversion/subversion_core.cpp26
-rw-r--r--vcs/subversion/subversion_core.h4
-rw-r--r--vcs/subversion/subversion_fileinfo.cpp6
-rw-r--r--vcs/subversion/subversion_fileinfo.h4
-rw-r--r--vcs/subversion/subversion_part.cpp26
-rw-r--r--vcs/subversion/subversion_part.h12
-rw-r--r--vcs/subversion/subversion_widget.cpp2
-rw-r--r--vcs/subversion/svn_fileselectdlg_commit.cpp4
-rw-r--r--vcs/subversion/svn_logviewwidget.cpp2
-rw-r--r--vcs/subversion/svn_tdeio.cpp4
31 files changed, 105 insertions, 105 deletions
diff --git a/vcs/subversion/CMakeLists.txt b/vcs/subversion/CMakeLists.txt
index 63ffad4b..fb51fe3d 100644
--- a/vcs/subversion/CMakeLists.txt
+++ b/vcs/subversion/CMakeLists.txt
@@ -31,19 +31,19 @@ link_directories(
##### other data ################################
install( FILES
- tdevsubversion.desktop tdevsvn+file.protocol
- tdevsvn+http.protocol tdevsvn+https.protocol
- tdevsvn+ssh.protocol tdevsvn+svn.protocol
+ kdevsubversion.desktop kdevsvn+file.protocol
+ kdevsvn+http.protocol kdevsvn+https.protocol
+ kdevsvn+ssh.protocol kdevsvn+svn.protocol
DESTINATION ${SERVICES_INSTALL_DIR} )
install( FILES
- tdevsvnd.desktop
+ kdevsvnd.desktop
DESTINATION ${SERVICES_INSTALL_DIR}/kded )
-##### libtdevsubversion (module) ################
+##### libkdevsubversion (module) ################
-tde_add_kpart( libtdevsubversion AUTOMOC
+tde_add_kpart( libkdevsubversion AUTOMOC
SOURCES
subversion_core.cpp subversion_fileinfo.cpp
subversion_fileinfo.skel subversion_part.cpp
@@ -54,14 +54,14 @@ tde_add_kpart( libtdevsubversion AUTOMOC
svn_logviewoptiondlgbase.ui svn_logviewwidget.cpp
svn_mergeoptiondlgbase.ui svn_mergewidget.cpp
svn_switchdlgbase.ui svn_switchwidget.cpp
- LINK tdevextensions-static tdevelop-shared
+ LINK kdevextensions-static tdevelop-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
-##### tdeio_tdevsvn (module) ######################
+##### tdeio_kdevsvn (module) ######################
-tde_add_kpart( tdeio_tdevsvn AUTOMOC
+tde_add_kpart( tdeio_kdevsvn AUTOMOC
SOURCES
svn_tdeio.cpp
LINK tdeio-shared ${SVN_LIBRARIES} ${APR_LIBRARIES}
@@ -69,12 +69,12 @@ tde_add_kpart( tdeio_tdevsvn AUTOMOC
)
-##### kded_tdevsvnd (module) ####################
+##### kded_kdevsvnd (module) ####################
-tde_add_kpart( kded_tdevsvnd AUTOMOC
+tde_add_kpart( kded_kdevsvnd AUTOMOC
SOURCES
- commitdlg.cpp commitdlgbase.ui tdevsvnd.cpp tdevsvnd.skel
- tdevsvnd_widgets.cpp svnssltrustpromptbase.ui
+ commitdlg.cpp commitdlgbase.ui kdevsvnd.cpp kdevsvnd.skel
+ kdevsvnd_widgets.cpp svnssltrustpromptbase.ui
LINK tdeio-shared tdeinit_kded-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/vcs/subversion/Makefile.am b/vcs/subversion/Makefile.am
index 2f650195..a66b80dd 100644
--- a/vcs/subversion/Makefile.am
+++ b/vcs/subversion/Makefile.am
@@ -2,37 +2,37 @@ INCLUDES = -I$(top_srcdir)/lib/interfaces -I$(top_srcdir)/lib/util -I$(top_srcdi
METASOURCES = AUTO
-kde_module_LTLIBRARIES = libtdevsubversion.la tdeio_tdevsvn.la kded_tdevsvnd.la
+kde_module_LTLIBRARIES = libkdevsubversion.la tdeio_kdevsvn.la kded_kdevsvnd.la
-libtdevsubversion_la_SOURCES = subversion_core.cpp subversion_fileinfo.cpp \
+libkdevsubversion_la_SOURCES = subversion_core.cpp subversion_fileinfo.cpp \
subversion_fileinfo.skel subversion_part.cpp subversion_widget.cpp subversiondiff.ui \
subversionprojectwidget.ui svn_blamewidget.cpp svn_co.ui svn_commitdlgbase.ui svn_copydlgwidget.ui \
svn_copywidget.cpp svn_fileselectdlg_commit.cpp svn_logviewoptiondlgbase.ui \
svn_logviewwidget.cpp svn_mergeoptiondlgbase.ui svn_mergewidget.cpp svn_switchdlgbase.ui \
svn_switchwidget.cpp
-libtdevsubversion_la_LIBADD = $(top_builddir)/lib/libtdevelop.la $(top_builddir)/lib/interfaces/extensions/libtdevextensions.la
-libtdevsubversion_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN)
+libkdevsubversion_la_LIBADD = $(top_builddir)/lib/libtdevelop.la $(top_builddir)/lib/interfaces/extensions/libkdevextensions.la
+libkdevsubversion_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN)
-tdeio_tdevsvn_la_SOURCES = svn_tdeio.cpp
-tdeio_tdevsvn_la_LIBADD = $(LIB_TDEIO)
-tdeio_tdevsvn_la_LDFLAGS = -module $(all_libraries) $(KDE_PLUGIN) $(SVN_LIB)
+tdeio_kdevsvn_la_SOURCES = svn_tdeio.cpp
+tdeio_kdevsvn_la_LIBADD = $(LIB_TDEIO)
+tdeio_kdevsvn_la_LDFLAGS = -module $(all_libraries) $(KDE_PLUGIN) $(SVN_LIB)
-kded_tdevsvnd_la_SOURCES = commitdlg.cpp commitdlgbase.ui tdevsvnd.cpp \
- tdevsvnd.skel tdevsvnd_widgets.cpp svnssltrustpromptbase.ui
-kded_tdevsvnd_la_LIBADD = $(LIB_TDEIO) -ltdeinit_kded
-kded_tdevsvnd_la_LDFLAGS = -module $(all_libraries) $(KDE_PLUGIN)
+kded_kdevsvnd_la_SOURCES = commitdlg.cpp commitdlgbase.ui kdevsvnd.cpp \
+ kdevsvnd.skel kdevsvnd_widgets.cpp svnssltrustpromptbase.ui
+kded_kdevsvnd_la_LIBADD = $(LIB_TDEIO) -ltdeinit_kded
+kded_kdevsvnd_la_LDFLAGS = -module $(all_libraries) $(KDE_PLUGIN)
kdeddir = $(kde_servicesdir)/kded
-kded_DATA = tdevsvnd.desktop
+kded_DATA = kdevsvnd.desktop
servicedir = $(kde_servicesdir)
-service_DATA = tdevsubversion.desktop
+service_DATA = kdevsubversion.desktop
protocoldir = $(kde_servicesdir)
-protocol_DATA = tdevsvn+file.protocol tdevsvn+http.protocol tdevsvn+https.protocol tdevsvn+ssh.protocol tdevsvn+svn.protocol
+protocol_DATA = kdevsvn+file.protocol kdevsvn+http.protocol kdevsvn+https.protocol kdevsvn+ssh.protocol kdevsvn+svn.protocol
SUBDIRS = integrator
-noinst_HEADERS = commitdlg.h tdevsvnd.h svn_blamewidget.h svn_copywidget.h \
+noinst_HEADERS = commitdlg.h kdevsvnd.h svn_blamewidget.h svn_copywidget.h \
svn_fileselectdlg_commit.h svn_logviewwidget.h svn_mergewidget.h svn_switchwidget.h
diff --git a/vcs/subversion/integrator/CMakeLists.txt b/vcs/subversion/integrator/CMakeLists.txt
index 3d6c7ad3..2256b8e3 100644
--- a/vcs/subversion/integrator/CMakeLists.txt
+++ b/vcs/subversion/integrator/CMakeLists.txt
@@ -26,7 +26,7 @@ link_directories(
##### other data ################################
-install( FILES tdevsubversionintegrator.desktop DESTINATION ${SERVICES_INSTALL_DIR} )
+install( FILES kdevsubversionintegrator.desktop DESTINATION ${SERVICES_INSTALL_DIR} )
##### libsubversionintegrator (module) ##########
@@ -35,6 +35,6 @@ tde_add_kpart( libsubversionintegrator AUTOMOC
SOURCES
subversionintegrator.cpp svnintegratordlgbase.ui
svnintegratordlg.cpp
- LINK tdevextras-shared tdevelop-shared
+ LINK kdevextras-shared tdevelop-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/vcs/subversion/integrator/Makefile.am b/vcs/subversion/integrator/Makefile.am
index aded8465..231dc3c7 100644
--- a/vcs/subversion/integrator/Makefile.am
+++ b/vcs/subversion/integrator/Makefile.am
@@ -6,9 +6,9 @@ METASOURCES = AUTO
kde_module_LTLIBRARIES = libsubversionintegrator.la
libsubversionintegrator_la_LDFLAGS = -avoid-version -no-undefined $(all_libraries)
libsubversionintegrator_la_LIBADD =\
- $(top_builddir)/lib/interfaces/extras/libtdevextras.la\
+ $(top_builddir)/lib/interfaces/extras/libkdevextras.la\
$(top_builddir)/lib/libtdevelop.la
-kde_services_DATA = tdevsubversionintegrator.desktop
+kde_services_DATA = kdevsubversionintegrator.desktop
noinst_HEADERS = subversionintegrator.h svnintegratordlg.h
libsubversionintegrator_la_SOURCES = subversionintegrator.cpp \
svnintegratordlgbase.ui svnintegratordlg.cpp
diff --git a/vcs/subversion/integrator/tdevsubversionintegrator.desktop b/vcs/subversion/integrator/kdevsubversionintegrator.desktop
index 6e666667..6e666667 100644
--- a/vcs/subversion/integrator/tdevsubversionintegrator.desktop
+++ b/vcs/subversion/integrator/kdevsubversionintegrator.desktop
diff --git a/vcs/subversion/integrator/subversionintegrator.cpp b/vcs/subversion/integrator/subversionintegrator.cpp
index da8fed8c..32d28d27 100644
--- a/vcs/subversion/integrator/subversionintegrator.cpp
+++ b/vcs/subversion/integrator/subversionintegrator.cpp
@@ -19,19 +19,19 @@
***************************************************************************/
#include "subversionintegrator.h"
-#include <tdevgenericfactory.h>
-#include <tdevplugininfo.h>
+#include <kdevgenericfactory.h>
+#include <kdevplugininfo.h>
#include "svnintegratordlg.h"
-static const TDevPluginInfo data("tdevsubversionintegrator");
-typedef TDevGenericFactory<SubversionIntegrator> SubversionIntegratorFactory;
+static const KDevPluginInfo data("kdevsubversionintegrator");
+typedef KDevGenericFactory<SubversionIntegrator> SubversionIntegratorFactory;
K_EXPORT_COMPONENT_FACTORY( libsubversionintegrator, SubversionIntegratorFactory(data) )
SubversionIntegrator::SubversionIntegrator(TQObject* parent, const char* name,
const TQStringList // args
)
- :TDevVCSIntegrator(parent, name)
+ :KDevVCSIntegrator(parent, name)
{
}
diff --git a/vcs/subversion/integrator/subversionintegrator.h b/vcs/subversion/integrator/subversionintegrator.h
index 6c7d16ac..01c43516 100644
--- a/vcs/subversion/integrator/subversionintegrator.h
+++ b/vcs/subversion/integrator/subversionintegrator.h
@@ -20,11 +20,11 @@
#ifndef SUBVERSIONINTEGRATOR_H
#define SUBVERSIONINTEGRATOR_H
-#include <tdevvcsintegrator.h>
+#include <kdevvcsintegrator.h>
#include <tqstringlist.h>
-class SubversionIntegrator : public TDevVCSIntegrator
+class SubversionIntegrator : public KDevVCSIntegrator
{
Q_OBJECT
diff --git a/vcs/subversion/integrator/svnintegratordlg.cpp b/vcs/subversion/integrator/svnintegratordlg.cpp
index 35e4216b..87ccf488 100644
--- a/vcs/subversion/integrator/svnintegratordlg.cpp
+++ b/vcs/subversion/integrator/svnintegratordlg.cpp
@@ -47,7 +47,7 @@ SvnIntegratorDlg::SvnIntegratorDlg( TQWidget *parent, const char *name )
void SvnIntegratorDlg::accept()
{
// to let ioslave know which protocol it should start.
- KURL protocolUrl = KURL("tdevsvn+svn://blah/");
+ KURL protocolUrl = KURL("kdevsvn+svn://blah/");
KURL servURL( repos1->url() );
if ( servURL.isEmpty() ) return;
diff --git a/vcs/subversion/integrator/svnintegratordlg.h b/vcs/subversion/integrator/svnintegratordlg.h
index bc8e8407..ccf1686f 100644
--- a/vcs/subversion/integrator/svnintegratordlg.h
+++ b/vcs/subversion/integrator/svnintegratordlg.h
@@ -21,7 +21,7 @@
#define SVNINTEGRATORDLG_H
#include "svnintegratordlgbase.h"
-#include <tdevvcsintegrator.h>
+#include <kdevvcsintegrator.h>
class SvnIntegratorDlg: public SvnIntegratorDlgBase, public VCSDialog {
Q_OBJECT
diff --git a/vcs/subversion/tdevpart_subversion.rc b/vcs/subversion/kdevpart_subversion.rc
index ad957e99..ad957e99 100644
--- a/vcs/subversion/tdevpart_subversion.rc
+++ b/vcs/subversion/kdevpart_subversion.rc
diff --git a/vcs/subversion/tdevsubversion.desktop b/vcs/subversion/kdevsubversion.desktop
index 7643c755..bf52db8c 100644
--- a/vcs/subversion/tdevsubversion.desktop
+++ b/vcs/subversion/kdevsubversion.desktop
@@ -29,6 +29,6 @@ GenericName[ta]=துணை பதிப்பு
GenericName[tg]=Зер-ривоят
Icon=misc
ServiceTypes=TDevelop/VersionControl
-X-TDE-Library=libtdevsubversion
+X-TDE-Library=libkdevsubversion
X-TDevelop-Version=5
X-TDevelop-Properties=VCS,SubversionVCS
diff --git a/vcs/subversion/tdevsvn+file.protocol b/vcs/subversion/kdevsvn+file.protocol
index 412c3800..412c3800 100644
--- a/vcs/subversion/tdevsvn+file.protocol
+++ b/vcs/subversion/kdevsvn+file.protocol
diff --git a/vcs/subversion/tdevsvn+http.protocol b/vcs/subversion/kdevsvn+http.protocol
index 5a063b85..5a063b85 100644
--- a/vcs/subversion/tdevsvn+http.protocol
+++ b/vcs/subversion/kdevsvn+http.protocol
diff --git a/vcs/subversion/tdevsvn+https.protocol b/vcs/subversion/kdevsvn+https.protocol
index d064e575..d064e575 100644
--- a/vcs/subversion/tdevsvn+https.protocol
+++ b/vcs/subversion/kdevsvn+https.protocol
diff --git a/vcs/subversion/tdevsvn+ssh.protocol b/vcs/subversion/kdevsvn+ssh.protocol
index 512b4a90..512b4a90 100644
--- a/vcs/subversion/tdevsvn+ssh.protocol
+++ b/vcs/subversion/kdevsvn+ssh.protocol
diff --git a/vcs/subversion/tdevsvn+svn.protocol b/vcs/subversion/kdevsvn+svn.protocol
index 8f496854..8f496854 100644
--- a/vcs/subversion/tdevsvn+svn.protocol
+++ b/vcs/subversion/kdevsvn+svn.protocol
diff --git a/vcs/subversion/tdevsvnd.desktop b/vcs/subversion/kdevsvnd.desktop
index 9ba3e877..9ba3e877 100644
--- a/vcs/subversion/tdevsvnd.desktop
+++ b/vcs/subversion/kdevsvnd.desktop
diff --git a/vcs/subversion/tdevsvnd.h b/vcs/subversion/kdevsvnd.h
index 4bec5ae7..438520e1 100644
--- a/vcs/subversion/tdevsvnd.h
+++ b/vcs/subversion/kdevsvnd.h
@@ -26,7 +26,7 @@
#include <kurl.h>
#include <tqstringlist.h>
-class TDevSvnd : public KDEDModule
+class KDevSvnd : public KDEDModule
{
Q_OBJECT
//
@@ -36,8 +36,8 @@ K_DCOP
//note: InSVN means parent is added. InRepos means itself is added
enum { SomeAreFiles = 1, SomeAreFolders = 2, SomeAreInParentsEntries = 4, SomeParentsHaveSvn = 8, SomeHaveSvn = 16, SomeAreExternalToParent = 32, AllAreInParentsEntries = 64, AllParentsHaveSvn = 128, AllHaveSvn = 256, AllAreExternalToParent = 512, AllAreFolders = 1024 };
public:
- TDevSvnd(const TQCString &);
- ~TDevSvnd();
+ KDevSvnd(const TQCString &);
+ ~KDevSvnd();
k_dcop:
// void addAuthInfo(TDEIO::AuthInfo, long);
diff --git a/vcs/subversion/tdevsvnd_widgets.cpp b/vcs/subversion/kdevsvnd_widgets.cpp
index ba688423..0fd2c20b 100644
--- a/vcs/subversion/tdevsvnd_widgets.cpp
+++ b/vcs/subversion/kdevsvnd_widgets.cpp
@@ -12,7 +12,7 @@
* Library General Public License for more details.
*/
-#include "tdevsvnd_widgets.h"
+#include "kdevsvnd_widgets.h"
#include <tqpushbutton.h>
#include <tqlistview.h>
#include <tqlabel.h>
@@ -67,4 +67,4 @@ void SvnSSLTrustPrompt::setRejected()
{
m_code = -1;
}
-#include "tdevsvnd_widgets.moc"
+#include "kdevsvnd_widgets.moc"
diff --git a/vcs/subversion/tdevsvnd_widgets.h b/vcs/subversion/kdevsvnd_widgets.h
index da7942b2..3967cb35 100644
--- a/vcs/subversion/tdevsvnd_widgets.h
+++ b/vcs/subversion/kdevsvnd_widgets.h
@@ -12,8 +12,8 @@
* Library General Public License for more details.
*/
-#ifndef TDEVSVND_WIDGETS_H
-#define TDEVSVND_WIDGETS_H
+#ifndef KDEVSVND_WIDGETS_H
+#define KDEVSVND_WIDGETS_H
#include "svnssltrustpromptbase.h"
diff --git a/vcs/subversion/subversion_core.cpp b/vcs/subversion/subversion_core.cpp
index 108bf298..e9c89ece 100644
--- a/vcs/subversion/subversion_core.cpp
+++ b/vcs/subversion/subversion_core.cpp
@@ -18,15 +18,15 @@
*/
#include <tdeparts/part.h>
-#include <tdevcore.h>
-#include <tdevproject.h>
+#include <kdevcore.h>
+#include <kdevproject.h>
#include "subversion_part.h"
#include "subversion_core.h"
#include "subversion_widget.h"
#include "svn_blamewidget.h"
#include "svn_logviewwidget.h"
#include "subversiondiff.h"
-#include <tdevmainwindow.h>
+#include <kdevmainwindow.h>
#include "svn_co.h"
#include <kurlrequester.h>
#include <klineedit.h>
@@ -82,7 +82,7 @@ subversionCore::~subversionCore() {
//FIXME delete m_fileInfoProvider here?
}
-TDevVCSFileInfoProvider *subversionCore::fileInfoProvider() const {
+KDevVCSFileInfoProvider *subversionCore::fileInfoProvider() const {
return m_fileInfoProvider;
}
@@ -114,8 +114,8 @@ subversionWidget *subversionCore::processWidget() const {
void subversionCore::resolve( const KURL::List& list ) {
KURL servURL = m_part->baseURL();
if ( servURL.isEmpty() ) servURL="kdevsvn+svn://blah/";
- if ( ! servURL.protocol().startsWith( "tdevsvn+" ) ) {
- servURL.setProtocol( "tdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
+ if ( ! servURL.protocol().startsWith( "kdevsvn+" ) ) {
+ servURL.setProtocol( "kdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
}
kdDebug(9036) << "servURL : " << servURL.prettyURL() << endl;
for ( TQValueListConstIterator<KURL> it = list.begin(); it != list.end() ; ++it ) {
@@ -248,8 +248,8 @@ void subversionCore::diffAsync( const KURL &pathOrUrl1, const KURL &pathOrUrl2,
void subversionCore::commit( const KURL::List& list, bool recurse, bool keeplocks ) {
KURL servURL = m_part->baseURL();
if ( servURL.isEmpty() ) servURL="kdevsvn+svn://blah/";
- if ( ! servURL.protocol().startsWith( "tdevsvn+" ) ) {
- servURL.setProtocol( "tdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
+ if ( ! servURL.protocol().startsWith( "kdevsvn+" ) ) {
+ servURL.setProtocol( "kdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
}
kdDebug(9036) << "servURL : " << servURL.prettyURL() << endl;
TQByteArray parms;
@@ -277,8 +277,8 @@ void subversionCore::svnLog( const KURL::List& list,
clientInfo( KURL(m_part->project()->projectDirectory()), false, m_part->m_prjInfoMap );
KURL servURL = m_part->baseURL();
if ( servURL.isEmpty() ) servURL="kdevsvn+svn://blah/";
- if ( ! servURL.protocol().startsWith( "tdevsvn+" ) ) {
- servURL.setProtocol( "tdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
+ if ( ! servURL.protocol().startsWith( "kdevsvn+" ) ) {
+ servURL.setProtocol( "kdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
}
kdDebug(9036) << "servURL : " << servURL.prettyURL() << endl;
TQByteArray parms;
@@ -304,8 +304,8 @@ void subversionCore::blame( const KURL &url, UrlMode mode, int revstart, TQStrin
{
KURL servURL = m_part->baseURL();
if ( servURL.isEmpty() ) servURL="kdevsvn+svn://blah/";
- if ( ! servURL.protocol().startsWith( "tdevsvn+" ) ) {
- servURL.setProtocol( "tdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
+ if ( ! servURL.protocol().startsWith( "kdevsvn+" ) ) {
+ servURL.setProtocol( "kdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
}
kdDebug(9036) << "servURL : " << servURL.prettyURL() << endl;
TQByteArray parms;
@@ -374,7 +374,7 @@ void subversionCore::checkout() {
int cmd = 1;
int rev = -1;
s << cmd << servURL << KURL( wcPath ) << rev << TQString( "HEAD" );
- servURL.setProtocol( "tdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
+ servURL.setProtocol( "kdevsvn+" + servURL.protocol() ); //make sure it starts with "svn"
SimpleJob * job = TDEIO::special(servURL,parms, true);
job->setWindow( m_part->mainWindow()->main() );
connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotEndCheckout( TDEIO::Job * ) ) );
diff --git a/vcs/subversion/subversion_core.h b/vcs/subversion/subversion_core.h
index 60cd8cfc..f2f3f6da 100644
--- a/vcs/subversion/subversion_core.h
+++ b/vcs/subversion/subversion_core.h
@@ -29,7 +29,7 @@
#include "subversion_fileinfo.h"
#include "subversion_global.h"
-class TDevProject;
+class KDevProject;
class subversionPart;
class subversionWidget;
class TDEApplication;
@@ -76,7 +76,7 @@ public:
// Return true on success. Otherwise return false.
bool clientInfo( KURL path_or_url, bool recurse, TQMap< KURL, SvnGlobal::SvnInfoHolder> &holderMap );
void createNewProject( const TQString& dirName, const KURL& importURL, bool init );
- TDevVCSFileInfoProvider *fileInfoProvider() const;
+ KDevVCSFileInfoProvider *fileInfoProvider() const;
void initProcessDlg( TDEIO::Job *job, const TQString &src, const TQString &dest );
// k_dcop:
diff --git a/vcs/subversion/subversion_fileinfo.cpp b/vcs/subversion/subversion_fileinfo.cpp
index c41ff9ef..45d44d1e 100644
--- a/vcs/subversion/subversion_fileinfo.cpp
+++ b/vcs/subversion/subversion_fileinfo.cpp
@@ -22,10 +22,10 @@
#include <kdebug.h>
#include <tqfileinfo.h>
#include <tqdir.h>
-#include <tdevproject.h>
+#include <kdevproject.h>
#include <unistd.h>
#include <tdeapplication.h>
-#include <tdevmainwindow.h>
+#include <kdevmainwindow.h>
#include <tdemainwindow.h>
#include <tqregexp.h>
@@ -33,7 +33,7 @@
#include <tdelocale.h>
SVNFileInfoProvider::SVNFileInfoProvider(subversionPart *parent, const char *name)
- : TDevVCSFileInfoProvider( parent, "svnfileinfoprovider" ),
+ : KDevVCSFileInfoProvider( parent, "svnfileinfoprovider" ),
m_cachedDirEntries( 0 ), m_recursiveDirEntries(0) {
Q_UNUSED(name);
m_part = parent;
diff --git a/vcs/subversion/subversion_fileinfo.h b/vcs/subversion/subversion_fileinfo.h
index 1d144270..9b322463 100644
--- a/vcs/subversion/subversion_fileinfo.h
+++ b/vcs/subversion/subversion_fileinfo.h
@@ -23,7 +23,7 @@
#include <tqmap.h>
-#include <tdevversioncontrol.h>
+#include <kdevversioncontrol.h>
#include <tdeio/job.h>
#include <dcopclient.h>
#include <dcopobject.h>
@@ -34,7 +34,7 @@ Provider for SVN file information
@author Mickael Marchand
*/
-class SVNFileInfoProvider : public TDevVCSFileInfoProvider, public DCOPObject/*, virtual public DCOPClient*/
+class SVNFileInfoProvider : public KDevVCSFileInfoProvider, public DCOPObject/*, virtual public DCOPClient*/
{
Q_OBJECT
//
diff --git a/vcs/subversion/subversion_part.cpp b/vcs/subversion/subversion_part.cpp
index 3df326d9..f3f43cd9 100644
--- a/vcs/subversion/subversion_part.cpp
+++ b/vcs/subversion/subversion_part.cpp
@@ -21,18 +21,18 @@
#include <tqwhatsthis.h>
#include <kiconloader.h>
#include <tdelocale.h>
-#include <tdevgenericfactory.h>
+#include <kdevgenericfactory.h>
#include <tdeaction.h>
#include <tdepopupmenu.h>
-#include "tdevcore.h"
-#include "tdevmainwindow.h"
+#include "kdevcore.h"
+#include "kdevmainwindow.h"
#include "subversion_core.h"
#include "subversion_widget.h"
#include "subversionprojectwidget.h"
#include "subversion_fileinfo.h"
#include "subversion_global.h"
-#include "tdevversioncontrol.h"
+#include "kdevversioncontrol.h"
#include "svn_fileselectdlg_commit.h"
#include "svn_logviewwidget.h"
#include "svn_switchwidget.h"
@@ -43,28 +43,28 @@
#include <tqvbox.h>
#include <kdialogbase.h>
#include <tdeparts/part.h>
-#include <tdevpartcontroller.h>
-#include <tdevproject.h>
+#include <kdevpartcontroller.h>
+#include <kdevproject.h>
#include <domutil.h>
#include <kurlrequester.h>
#include <tqradiobutton.h>
#include <kdebug.h>
#include <tqwidget.h>
-#include <tdevplugininfo.h>
+#include <kdevplugininfo.h>
#include <tdemessagebox.h>
using namespace SvnGlobal;
-static const TDevPluginInfo data("tdevsubversion");
+static const KDevPluginInfo data("kdevsubversion");
-typedef TDevGenericFactory<subversionPart> subversionFactory;
-K_EXPORT_COMPONENT_FACTORY( libtdevsubversion, subversionFactory( data ) )
+typedef KDevGenericFactory<subversionPart> subversionFactory;
+K_EXPORT_COMPONENT_FACTORY( libkdevsubversion, subversionFactory( data ) )
//bool g_projectWasJustCreated = false;
subversionPart::subversionPart(TQObject *parent, const char *name, const TQStringList& )
- : TDevVersionControl(&data, parent, name ? name : "Subversion" ) {
+ : KDevVersionControl(&data, parent, name ? name : "Subversion" ) {
setInstance(subversionFactory::instance());
m_projWidget = 0;
@@ -79,7 +79,7 @@ subversionPart::subversionPart(TQObject *parent, const char *name, const TQStrin
// Context menu
connect( core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)), this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)) );
connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)), this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
- connect( core(), TQT_SIGNAL(stopButtonClicked(TDevPlugin*)), this, TQT_SLOT(slotStopButtonClicked(TDevPlugin*)) );
+ connect( core(), TQT_SIGNAL(stopButtonClicked(KDevPlugin*)), this, TQT_SLOT(slotStopButtonClicked(KDevPlugin*)) );
connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(slotProjectOpened()) );
connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(slotProjectClosed()) );
@@ -177,7 +177,7 @@ bool subversionPart::fetchFromRepository() {
return true;
}
-TDevVCSFileInfoProvider * subversionPart::fileInfoProvider() const {
+KDevVCSFileInfoProvider * subversionPart::fileInfoProvider() const {
return m_impl->fileInfoProvider();
}
diff --git a/vcs/subversion/subversion_part.h b/vcs/subversion/subversion_part.h
index 9296152a..1847567d 100644
--- a/vcs/subversion/subversion_part.h
+++ b/vcs/subversion/subversion_part.h
@@ -16,16 +16,16 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef __TDEVPART_SUBVERSION_H__
-#define __TDEVPART_SUBVERSION_H__
+#ifndef __KDEVPART_SUBVERSION_H__
+#define __KDEVPART_SUBVERSION_H__
#include <tqguardedptr.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
#include <kurl.h>
#include <tqpopupmenu.h>
#include <kdialogbase.h>
-#include "tdevversioncontrol.h"
+#include "kdevversioncontrol.h"
class subversionCore;
class subversionOptionsWidget;
@@ -36,7 +36,7 @@ namespace SvnGlobal
class SvnInfoHolder;
};
-class subversionPart : public TDevVersionControl
+class subversionPart : public KDevVersionControl
{
Q_OBJECT
@@ -49,7 +49,7 @@ public:
TQWidget* newProjectWidget( TQWidget* parent );
void createNewProject( const TQString& dirname );
bool fetchFromRepository();
- TDevVCSFileInfoProvider * fileInfoProvider() const;
+ KDevVCSFileInfoProvider * fileInfoProvider() const;
bool urlFocusedDocument( KURL &url );
void restorePartialProjectSession(const TQDomElement* );
void savePartialProjectSession(TQDomElement* );
diff --git a/vcs/subversion/subversion_widget.cpp b/vcs/subversion/subversion_widget.cpp
index 9b29e1fa..95b31f6b 100644
--- a/vcs/subversion/subversion_widget.cpp
+++ b/vcs/subversion/subversion_widget.cpp
@@ -18,7 +18,7 @@
*/
#include <tdeparts/part.h>
-#include <tdevcore.h>
+#include <kdevcore.h>
#include <kdebug.h>
#include <klineedit.h>
diff --git a/vcs/subversion/svn_fileselectdlg_commit.cpp b/vcs/subversion/svn_fileselectdlg_commit.cpp
index 9c210a37..e042df84 100644
--- a/vcs/subversion/svn_fileselectdlg_commit.cpp
+++ b/vcs/subversion/svn_fileselectdlg_commit.cpp
@@ -29,10 +29,10 @@
#include <tqcheckbox.h>
#include <kdebug.h>
#include <tdemessagebox.h>
-#include "tdevmainwindow.h"
+#include "kdevmainwindow.h"
#include <tdelocale.h>
-#include <tdevproject.h>
+#include <kdevproject.h>
SVNFileSelectDlgCommit::SVNFileSelectDlgCommit( KURL::List &urls, subversionPart *part, TQWidget* parent)
:SvnCommitDlgBase( parent, "svnfileselectcommitdlg", true )
diff --git a/vcs/subversion/svn_logviewwidget.cpp b/vcs/subversion/svn_logviewwidget.cpp
index e872a586..10e55a9f 100644
--- a/vcs/subversion/svn_logviewwidget.cpp
+++ b/vcs/subversion/svn_logviewwidget.cpp
@@ -22,7 +22,7 @@
#include "svn_blamewidget.h"
#include "subversion_core.h"
#include "subversion_global.h"
-#include <tdevproject.h>
+#include <kdevproject.h>
#include <ktextedit.h>
#include <tdemessagebox.h>
#include <kdebug.h>
diff --git a/vcs/subversion/svn_tdeio.cpp b/vcs/subversion/svn_tdeio.cpp
index 0abac2b8..23f1d2ff 100644
--- a/vcs/subversion/svn_tdeio.cpp
+++ b/vcs/subversion/svn_tdeio.cpp
@@ -124,7 +124,7 @@ tdeio_svnProtocol::tdeio_svnProtocol(const TQCString &pool_socket, const TQCStri
apr_initialize();
// Make sure to properly initialize svn client, besides other things, this sets up
// NLS support for environments that don't use UTF-8
- svn_cmdline_init("tdevsvnd",NULL);
+ svn_cmdline_init("kdevsvnd",NULL);
// CleanUP ctx preventing crash in svn_client_update and other
memset(&ctx, 0, sizeof(ctx));
pool = svn_pool_create (NULL);
@@ -1861,7 +1861,7 @@ svn_error_t *tdeio_svnProtocol::commitLogPrompt( const char **log_msg, const cha
kdDebug(9036) << " __TIME__ " << __TIME__ << endl;
if ( !p->dcopClient()->call( "kded","kdevsvnd","commitDialog(TQString)", params, replyType, reply ) ) {
- kdWarning() << "Communication with KDED:TDevSvnd failed" << endl;
+ kdWarning() << "Communication with KDED:KDevSvnd failed" << endl;
svn_error_t *err = svn_error_create( SVN_ERR_EXTERNAL_PROGRAM, NULL,
apr_pstrdup( pool, "Fail to call kded_kdevsvnd via DCOP. If this is your first problem, try to restart KDE" ) );
return err;
diff --git a/vcs/subversion/tdevsvnd.cpp b/vcs/subversion/kdevsvnd.cpp
index ea42667b..c1faf65e 100644
--- a/vcs/subversion/tdevsvnd.cpp
+++ b/vcs/subversion/kdevsvnd.cpp
@@ -30,24 +30,24 @@
#include "config.h"
-#include "tdevsvnd.h"
+#include "kdevsvnd.h"
-#include "tdevsvnd_widgets.h"
+#include "kdevsvnd_widgets.h"
#include "commitdlg.h"
extern "C" {
KDE_EXPORT KDEDModule *create_kdevsvnd(const TQCString &name) {
- return new TDevSvnd(name);
+ return new KDevSvnd(name);
}
}
-TDevSvnd::TDevSvnd(const TQCString &name)
+KDevSvnd::KDevSvnd(const TQCString &name)
: KDEDModule(name) {
}
-TDevSvnd::~TDevSvnd()
+KDevSvnd::~KDevSvnd()
{}
-TQString TDevSvnd::commitDialog(TQString modifiedFiles) {
+TQString KDevSvnd::commitDialog(TQString modifiedFiles) {
CommitDlg commitDlg;
commitDlg.setCaption(i18n("Enter Commit Log Message:"));
commitDlg.listMessage->setText( modifiedFiles );
@@ -57,7 +57,7 @@ TQString TDevSvnd::commitDialog(TQString modifiedFiles) {
} else
return TQString();
}
-int TDevSvnd::sslServerTrustPrompt( TQString errmsg, TQString hostname, TQString fingerPrint, TQString validfrom, TQString validuntil, TQString issuerName, TQString ascii_cert )
+int KDevSvnd::sslServerTrustPrompt( TQString errmsg, TQString hostname, TQString fingerPrint, TQString validfrom, TQString validuntil, TQString issuerName, TQString ascii_cert )
{
SvnSSLTrustPrompt dlg;
dlg.setupCertInfo( hostname, fingerPrint, validfrom, validuntil, issuerName, ascii_cert );
@@ -69,12 +69,12 @@ int TDevSvnd::sslServerTrustPrompt( TQString errmsg, TQString hostname, TQString
return -1;
}
}
-TQString TDevSvnd::sslCertFile()
+TQString KDevSvnd::sslCertFile()
{
TQString fileName = KFileDialog::getOpenFileName(TQString(),TQString(),0, i18n("Open SSL certificate file"));
return fileName;
}
-TQCString TDevSvnd::sslPasswdDlg(TQString promptMsg)
+TQCString KDevSvnd::sslPasswdDlg(TQString promptMsg)
{
TQCString passwd;
int ret = KPasswordDialog::getPassword( passwd,promptMsg );
@@ -90,7 +90,7 @@ TQCString TDevSvnd::sslPasswdDlg(TQString promptMsg)
}
// void TDevSvnd::registerMe(const TQCString &app)
// {
// insert(app, "test", new TestObject(app));
// // When 'app' unregisters with DCOP, the TestObject will get deleted.
@@ -391,4 +391,4 @@ TQCString TDevSvnd::sslPasswdDlg(TQString promptMsg)
// }
// #endif
-#include "tdevsvnd.moc"
+#include "kdevsvnd.moc"
@@ -90,7 +90,7 @@ TQCString TDevSvnd::sslPasswdDlg(TQString promptMsg)
}
-// void TDevSvnd::registerMe(const TQCString &app)
+// void KDevSvnd::registerMe(const TQCString &app)
// {
// insert(app, "test", new TestObject(app));